@@ -42,8 +42,13 @@ void gpx_free_wpt(wpt_t *wpt) {
   free(wpt);
 }
 
+void gpx_free_user(user_t *user) {
+  if(user->name) xmlFree(user->name);
+  free(user);
+}
+
 void gpx_free_log(log_t *log) {
-  if(log->finder)  xmlFree(log->finder);
+  if(log->finder)  gpx_free_user(log->finder);
   if(log->text)    xmlFree(log->text);
   free(log);
 }
@@ -61,7 +66,7 @@ void gpx_free_cache(cache_t *cache) {
 
   if(cache->id)                xmlFree(cache->id);
   if(cache->name)              xmlFree(cache->name);
-  if(cache->owner)             xmlFree(cache->owner);
+  if(cache->owner)             gpx_free_user(cache->owner);
   if(cache->short_description) xmlFree(cache->short_description);
   if(cache->long_description)  xmlFree(cache->long_description);
   if(cache->hint)              xmlFree(cache->hint);
@@ -267,7 +272,7 @@ void gpx_display_log(log_t *log) {
   printf("  Log:\n");
   printf("    date:     %d.%d.%d\n", log->day, log->month, log->year);
   printf("    type:     %s\n", log_type_str[log->type+1]);
-  printf("    finder:   %s\n", log->finder);
+  printf("    finder:   %s\n", log->finder->name);
   //  printf("    text:     %s\n", log->text);
 }
 
@@ -279,7 +284,7 @@ void gpx_display_cache(cache_t *cache) {
   printf("  name:       %s\n", cache->name);
   printf("  latitude:   %f\n", cache->pos.lat);
   printf("  longitude:  %f\n", cache->pos.lon);
-  printf("  owner:      %s\n", cache->owner);
+  printf("  owner:      %s\n", cache->owner->name);
   printf("  type:       %s\n", cache_type_str[cache->type+1]);
   printf("  container:  %s\n", cache_container_str[cache->container+1]);
   printf("  difficulty: %.1f\n", cache->difficulty);
@@ -326,6 +331,16 @@ static float xml_get_prop_float(xmlTextReaderPtr reader, char *name) {
   return ret;
 }
 
+static unsigned int xml_get_prop_id(xmlTextReaderPtr reader) {
+  unsigned int ret = 0;
+  char *prop;
+  if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "id"))) {
+    ret = atoi(prop);
+    xmlFree(prop);
+  }
+  return ret;
+}
+
 static int xml_prop_is(xmlTextReaderPtr reader, char *name, char *value, 
 		       int def_value) {
   int match = def_value;
@@ -446,7 +461,11 @@ static log_t *process_gpx_wpt_gc_logs_log(xmlTextReaderPtr reader) {
 	  log->type = xml_str_search(reader, log_type_str, "log", 0);
 	} else if((strcasecmp(name, "finder") == 0) ||
 		  (strcasecmp(name, "geocacher") == 0)) {
-	  if(!log->finder) log->finder = process_text(reader);
+	  if(!log->finder) {
+	    log->finder = g_new0(user_t, 1);
+	    log->finder->name = process_text(reader);
+	    log->finder->id = xml_get_prop_id(reader);
+	  }
 	} else if(strcasecmp(name, "text") == 0) {
 	  if(!log->text) log->text = process_text(reader);
 	} else
@@ -542,6 +561,9 @@ static tb_t *process_gpx_wpt_gc_tbs_travelbug(xmlTextReaderPtr reader) {
   else
     tb->ref = strdup("<NONE>");
 
+  if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "id"))) 
+    tb->id = atoi(prop);
+
   /* process all sub-nodes */
   int depth = xmlTextReaderDepth(reader);
   int ret = xmlTextReaderRead(reader);
@@ -645,7 +667,11 @@ static void process_gpx_wpt_gc(xmlTextReaderPtr reader, cache_t *cache) {
 	if(strcasecmp(name, "name") == 0) {
 	  if(!cache->name) cache->name = process_text(reader);
 	} else if(strcasecmp(name, "owner") == 0) {
-	  if(!cache->owner) cache->owner = process_text(reader);
+	  if(!cache->owner) {
+	    cache->owner = g_new0(user_t, 1);
+	    cache->owner->name = process_text(reader);
+	    cache->owner->id = xml_get_prop_id(reader);
+	  }
 	} else if(strcasecmp(name, "type") == 0) {
 	  cache->type = xml_str_search(reader, cache_type_str, 
 				       "cache type", CACHE_TYPE_UNKNOWN);
