@@ -754,7 +754,13 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
       GtkWidget *dialog = gtk_message_dialog_new(
   	         GTK_WINDOW(appdata->window),
 		 GTK_DIALOG_DESTROY_WITH_PARENT,
-		 GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL,
+		 /* this doesn't fix the text selection issues ... */
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR >=5)
+		 GTK_MESSAGE_OTHER,
+#else
+		 GTK_MESSAGE_QUESTION,
+#endif
+		 GTK_BUTTONS_CANCEL,
 		 _("Do you want to close this entry only or do "
 		   "you want to remove it completely from the list?"));
 
@@ -766,7 +772,7 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
       if(gpx->closed)
 	gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), 2, FALSE);
 
-      gtk_window_set_title(GTK_WINDOW(dialog), _("Remove entry?"));
+      gtk_window_set_title(GTK_WINDOW(dialog), _("Close or remove entry?"));
       
       /* set the active flag again if the user answered "no" */
       switch(gtk_dialog_run(GTK_DIALOG(dialog))) {
@@ -1850,11 +1856,8 @@ void menu_create(appdata_t *appdata) {
 
   gtk_menu_append(GTK_MENU_SHELL(menu), gtk_separator_menu_item_new());
  
-#ifndef NO_COPY_N_PASTE
   /* ----------- copy'n paste submenu ----------------- */
-  appdata->clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-  gtk_clipboard_set_can_store(appdata->clipboard, NULL, 0);
-
+#ifndef NO_COPY_N_PASTE
   item = gtk_menu_item_new_with_label(_("Edit"));
   gtk_menu_append(GTK_MENU_SHELL(menu), item);
   submenu = gtk_menu_new();
@@ -2327,6 +2330,10 @@ int main(int argc, char *argv[]) {
   g_signal_connect(G_OBJECT(appdata.window), "key_press_event",
 		   G_CALLBACK(on_window_key_press), &appdata);
 
+  /* prepare clipboard */
+  appdata.clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+  gtk_clipboard_set_can_store(appdata.clipboard, NULL, 0);
+
   appdata.vbox = gtk_vbox_new(FALSE, 2);
   gtk_container_add(GTK_CONTAINER(appdata.window), appdata.vbox);
 #ifndef USE_STACKABLE_WINDOW
