@@ -20,6 +20,8 @@
 #ifndef MAP_TOOL_H
 #define MAP_TOOL_H
 
+typedef enum { MAP_NONE=0, MAP_ALL, MAP_GPX, MAP_CACHE } map_state_t;
+
 typedef struct map_context_s {
   appdata_t *appdata;
   GtkWidget *window;
@@ -27,6 +29,8 @@ typedef struct map_context_s {
   gint handler_id;
   cache_t *press_on;
   gboolean map_complete;
+  map_state_t state;
+
 #if MAEMO_VERSION_MAJOR == 5
   GtkWidget *old_view;
 #endif
@@ -34,5 +38,6 @@ typedef struct map_context_s {
 
 
 extern void map(appdata_t *appdata);
+extern void map_update(appdata_t *appdata);
 
 #endif // MAP_TOOL_H
