@@ -76,5 +76,8 @@ extern int browser_url(appdata_t *appdata, char *url);
 #endif
 
 void rmdir_recursive(char *path);
-
+GtkWidget *link_button_attrib(appdata_t *appdata, char *str, char *url, 
+		       int size, int strikethrough);
+GtkWidget *link_button_by_id(appdata_t *appdata, char *str, 
+			     const char *type, int id);
 #endif // MISC_H
