@@ -157,7 +157,7 @@ void notes_load_all(appdata_t *appdata, gpx_t *gpx) {
   }
 }
 
-static int notes_save(cache_context_t *context,
+static int notes_write_file(cache_context_t *context,
 		      char *text, pos_t pos, 
 		      gboolean override, gboolean found, 
 		      time_t ftime, gboolean logged) {
@@ -230,12 +230,7 @@ static int notes_save(cache_context_t *context,
   return 0;
 }
 
-/* this is called from the destroy event of the entire notebook */
-gint notes_destroy_event(GtkWidget *widget, gpointer data ) {
-  cache_context_t *context = (cache_context_t*)data;
-
-  printf("about to destroy notes view\n");
-
+static void notes_save(cache_context_t *context) {
   /* only save if: there is a text which has been changed or */
   /* there is a position which differs from the original one */
   /* or has been changed */
@@ -333,8 +328,8 @@ gint notes_destroy_event(GtkWidget *widget, gpointer data ) {
       /* - update the notes entry in the loaded gpx tree */
       
       /* update file on disk */
-      notes_save(context, text, pos, override, found, 
-		 context->notes.ftime, logged);
+      notes_write_file(context, text, pos, override, found, 
+		       context->notes.ftime, logged);
     
       /* search for matching caches and replace note there */
       notes_t *note = NULL;
@@ -382,6 +377,14 @@ gint notes_destroy_event(GtkWidget *widget, gpointer data ) {
 
     if(text) free(text);
   }
+}
+
+/* this is called from the destroy event of the entire notebook */
+gint notes_destroy_event(GtkWidget *widget, gpointer data ) {
+  cache_context_t *context = (cache_context_t*)data;
+
+  printf("about to destroy notes view\n");
+  notes_save(context);
 
   return FALSE;
 }
@@ -519,6 +522,18 @@ static gboolean focus_in(GtkWidget *widget, GdkEventFocus *event,
 }
 #endif
 
+static gboolean focus_out(GtkWidget *widget, GdkEventFocus *event,
+			 gpointer data) {
+  cache_context_t *context = (cache_context_t*)data;
+
+  notes_save(context);
+#if !defined(USE_MAEMO) && defined(ENABLE_OSM_GPS_MAP)
+  map_update(context->appdata);
+#endif
+
+  return FALSE;
+}
+
 GtkWidget *cache_notes(cache_context_t *context) {
   cache_t *cache = context->cache;
 
@@ -575,10 +590,14 @@ GtkWidget *cache_notes(cache_context_t *context) {
   if(cache->notes) pos = cache->notes->pos;
 
   gtk_table_attach_defaults(GTK_TABLE(table), 
-	    context->notes.latw = lat_entry_new(pos.lat), 2, 3, 0, 1);
-
+			    context->notes.latw = lat_entry_new(pos.lat), 2, 3, 0, 1);
+  g_signal_connect(G_OBJECT(context->notes.latw), "focus-out-event", 
+		   G_CALLBACK(focus_out), context);
+  
   gtk_table_attach_defaults(GTK_TABLE(table), 
-	    context->notes.lonw = lon_entry_new(pos.lon), 2, 3, 1, 2);
+			    context->notes.lonw = lon_entry_new(pos.lon), 2, 3, 1, 2);
+  g_signal_connect(G_OBJECT(context->notes.lonw), "focus-out-event", 
+		   G_CALLBACK(focus_out), context);
 
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);  
@@ -946,7 +965,7 @@ void notes_log_export(appdata_t *appdata) {
 	ccontext.appdata = appdata;
 	ccontext.cache = llog->cache;
 
-	notes_save(&ccontext,
+	notes_write_file(&ccontext,
 		   llog->cache->notes->text, llog->cache->notes->pos, 
 		   llog->cache->notes->override, llog->cache->notes->found, 
 		   llog->cache->notes->ftime, llog->cache->notes->logged);
