@@ -1210,7 +1210,7 @@ osd_render_coordinates(osm_gps_map_osd_t *osd)
 
 #ifdef OSD_NAV
 #define OSD_NAV_W  (8*OSD_COORDINATES_FONT_SIZE+2*OSD_COORDINATES_OFFSET)
-#define OSD_NAV_H  (130)
+#define OSD_NAV_H  (11*OSD_COORDINATES_FONT_SIZE)
 
 /* http://mathforum.org/library/drmath/view/55417.html */
 static float get_bearing(float lat1, float lon1, float lat2, float lon2) {
