@@ -67,7 +67,6 @@ typedef enum {
     OSM_GPS_MAP_SOURCE_OPENSTREETMAP_RENDERER,
     OSM_GPS_MAP_SOURCE_OPENCYCLEMAP,
     OSM_GPS_MAP_SOURCE_GOOGLE_STREET,
-    OSM_GPS_MAP_SOURCE_GOOGLE_SATELLITE,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_STREET,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_SATELLITE,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_HYBRID,
@@ -76,6 +75,7 @@ typedef enum {
     OSM_GPS_MAP_SOURCE_OSMC_TRAILS,      /* only germany       */
     OSM_GPS_MAP_SOURCE_MAPS_FOR_FREE,    /* not enough details */
     OSM_GPS_MAP_SOURCE_GOOGLE_HYBRID,    /* disabled by google */
+    OSM_GPS_MAP_SOURCE_GOOGLE_SATELLITE, /* disabled by google */
     OSM_GPS_MAP_SOURCE_YAHOO_STREET,     /* no implemented yet */
     OSM_GPS_MAP_SOURCE_YAHOO_SATELLITE,  /* no implemented yet */
     OSM_GPS_MAP_SOURCE_YAHOO_HYBRID      /* no implemented yet */
